import { getLocations } from "@/app/lib/location/action";
import MultiMarkerMap from "../components/MultiMarkerMap";
import { SearchParamProps } from "@/types/searchParams";
import { getIbcRequestList } from "@/app/lib/ibc/action";
import { usersRequestList } from "@/app/lib/users/action";
import { prepareUsersDropdown } from "@/utils/common";
import { IbcInterface } from "@/types/settings/ibc/ibc";

export default async function History({ searchParams }: SearchParamProps) {
  const [locations, users, ibcs] = await Promise.all([
    getLocations(searchParams),
    usersRequestList({ pagination: 'false' }),
    getIbcRequestList({ pagination: 'false' }),
  ]);

  // Prepare data for users dropdown
  const usersDropdown = prepareUsersDropdown(users);

  // Prepare data for users dropdown
  const ibcsDropdown =
    ibcs?.data && ibcs?.data.length > 0
      ? ibcs?.data?.map((ibc: IbcInterface) => ({
        label: `${ibc.area_name}`,
        value: ibc.id,
      }))
      : [];

  return (
    <>
      {locations?.data && <MultiMarkerMap locations={locations?.data} users={usersDropdown} ibcs={ibcsDropdown} />}
    </>
  );
}
